# Antoine

Antoine is just one pip install away !
You can install Antoine directly using pip.

## Hire Antoine with a quick pip install

```bash
## Installing
pip install antoine

## Upgrading
pip install antoine --upgrade

## Running in terminal
$ hireantoine